Calculate confidence intervals for model parameters and their transformations using (1) delta method, (2) profile likelihood, and (3) importance sampling.
# S4 method for fitode
confint(
object,
parm,
level = 0.95,
method = c("delta", "profile", "impsamp", "wmvrnorm"),
nsim = 1000,
seed,
...
)The confidence intervals for model parameters and their transformations of the fitode object
fitode object
character vector specifying model parameters or list of formuals specifying transformations
the confidence level required
method for calculating confidence intervals
number of simulations to be used for importance sampling
seed
extra arguments passed to profiling method