Learn R Programming

fitode (version 0.1.1)

vcov,fitode-method: Extract variance-covariance matrix from fitode objects

Description

Extracts variance-covariance matrix (either on response scales or link scales)

Usage

# S4 method for fitode
vcov(object, type = c("response", "links"))

Value

The variance-covariance matrix of the fitode object

Arguments

object

fitode object

type

type of covariance matrix. The default (type=response) is on the response scale; this is the scale on which the model parameters are defined. Alternatively, type=link can be used to obtain the covariance matrix on the estimated scale.