Extracts variance-covariance matrix (either on response scales or link scales)
# S4 method for fitode
vcov(object, type = c("response", "links"))The variance-covariance matrix of the fitode object
fitode object
type of covariance matrix. The default (type=response) is on the
response scale; this is the scale on which the model parameters are defined.
Alternatively, type=link can be used to obtain the covariance matrix on the estimated scale.